/*
 * Segment 5 Intelligente Analyseverfahren, SWE 5.3 Automatisches Lernen
 * Ganglinien
 * Copyright (C) 2019 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.iav.gllernen.gllernen.domain;

import java.time.Duration;
import java.util.Objects;

import de.bsvrz.iav.gllib.gllib.shared.CronPattern;

/**
 * Repräsentation des Parameters "atg.ganglinienModellAutomatischesLernen", der
 * an der AOE eines Datenverteiler-Systems hinterlegt ist.
 * 
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public final class GanglinienModellAutomatischesLernen {

    private final CronPattern aktualisierungsIntervall;
    private final int maxVergleichsAbstand;
    private final Duration datenMindestalter;

    public static final GanglinienModellAutomatischesLernen STANDARD = GanglinienModellAutomatischesLernen
            .of(CronPattern.parse("0 3 * * *"), 25, Duration.ofDays(7));

    private GanglinienModellAutomatischesLernen(CronPattern aktualisierungsIntervall, int maxVergleichsAbstand,
            Duration datenMindestalter) {
        this.aktualisierungsIntervall = Objects.requireNonNull(aktualisierungsIntervall, "aktualisierungsIntervall");
        this.maxVergleichsAbstand = maxVergleichsAbstand;
        this.datenMindestalter = Objects.requireNonNull(datenMindestalter, "datenMindestalter");
    }

    public static GanglinienModellAutomatischesLernen of(CronPattern aktualisierungsIntervall, int maxVergleichsAbstand,
            Duration datenMindestalter) {
        return new GanglinienModellAutomatischesLernen(aktualisierungsIntervall, maxVergleichsAbstand,
                datenMindestalter);
    }

    public CronPattern getAktualisierungsintervall() {
        return aktualisierungsIntervall;
    }

    public int getMaxVergleichsAbstand() {
        return maxVergleichsAbstand;
    }

    public Duration getDatenMindestalter() {
        return datenMindestalter;
    }
}
